@@ -3,7 +3,8 @@ module Servant.API.HttpVersion
     HttpVersion(..)
   ) where
 
-import           Network.HTTP.Types (HttpVersion (..))
+import           Network.HTTP.Types
+                 (HttpVersion (..))
 
 -- $httpversion
 --
